'use strict';

exports.__esModule = true;

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _createClass = (function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ('value' in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; })();

exports['default'] = reduxForm;

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError('Cannot call a class as a function'); } }

function _inherits(subClass, superClass) { if (typeof superClass !== 'function' && superClass !== null) { throw new TypeError('Super expression must either be null or a function, not ' + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _actions = require('./actions');

var _util = require('./util');

/**
 * @param sliceName The key in the state corresponding to the data in this form
 * @param validate [optional] A validation function that takes all the data and returns all the errors
 */

function reduxForm(sliceName) {
  var validate = arguments.length <= 1 || arguments[1] === undefined ? function () {
    return {};
  } : arguments[1];

  return function (DecoratedComponent) {
    return (function (_Component) {
      _inherits(ReduxForm, _Component);

      function ReduxForm() {
        _classCallCheck(this, ReduxForm);

        _Component.apply(this, arguments);
      }

      ReduxForm.prototype.render = function render() {
        var _props = this.props;
        // eslint-disable-line no-shadow
        var form = _props.form;
        var sliceName = _props.sliceName;
        var dispatch = _props.dispatch;

        var passableProps = _objectWithoutProperties(_props, ['form', 'sliceName', 'dispatch']);

        passableProps.dispatch = dispatch; // we want to allow dispatch through
        var handleBlur = function handleBlur(name) {
          return function (event) {
            return dispatch(_actions.blur(sliceName, name, event.target.value));
          };
        };
        var handleChange = function handleChange(name) {
          return function (event) {
            return dispatch(_actions.change(sliceName, name, event.target.value));
          };
        };
        var pristine = _util.isPristine(form.initial, form.data);
        var errors = validate(form.data);
        var valid = !Object.keys(errors).length;
        return _react2['default'].createElement(DecoratedComponent, _extends({
          data: form.data,
          dirty: !pristine,
          errors: errors,
          handleBlur: handleBlur,
          handleChange: handleChange,
          initializeForm: function (data) {
            return dispatch(_actions.initialize(sliceName, data));
          },
          invalid: !valid,
          pristine: pristine,
          resetForm: function () {
            return dispatch(_actions.reset(sliceName));
          },
          touch: function () {
            for (var _len = arguments.length, fields = Array(_len), _key = 0; _key < _len; _key++) {
              fields[_key] = arguments[_key];
            }

            return dispatch(_actions.touch.apply(undefined, [sliceName].concat(fields)));
          },
          touched: form.touched,
          touchAll: function () {
            return dispatch(_actions.touchAll(sliceName));
          },
          untouch: function () {
            for (var _len2 = arguments.length, fields = Array(_len2), _key2 = 0; _key2 < _len2; _key2++) {
              fields[_key2] = arguments[_key2];
            }

            return dispatch(_actions.untouch.apply(undefined, [sliceName].concat(fields)));
          },
          untouchAll: function () {
            return dispatch(_actions.untouchAll(sliceName));
          },
          valid: valid
        }, passableProps)); // pass other props
      };

      _createClass(ReduxForm, null, [{
        key: 'displayName',
        value: 'ReduxForm(' + _util.getDisplayName(DecoratedComponent) + ')',
        enumerable: true
      }, {
        key: 'DecoratedComponent',
        value: DecoratedComponent,
        enumerable: true
      }, {
        key: 'propTypes',
        value: {
          sliceName: _react.PropTypes.string,
          form: _react.PropTypes.object.isRequired,
          dispatch: _react.PropTypes.func.isRequired
        },
        enumerable: true
      }, {
        key: 'defaultProps',
        value: {
          sliceName: sliceName
        },
        enumerable: true
      }]);

      return ReduxForm;
    })(_react.Component);
  };
}

module.exports = exports['default'];